@@ -292,9 +292,6 @@ class Workflow(base.Workflow):
     #: Save log to this django model (name of the model)
     log_model = get_default_log_model()
 
-    #: Run all transitions within a transaction.
-    implementation_class = TransactionalImplementationWrapper
-
     def __init__(self, *args, **kwargs):
         # Fetch 'log_model' if overridden.
         log_model = kwargs.pop('log_model', self.log_model)
